ColanderAlchemy
===============

`ColanderAlchemy` helps you autogenerating
`Colander <http://http://docs.pylonsproject.org/projects/colander/en/latest/>`_
schemas that are based on `SQLAlchemy <http://www.sqlalchemy.org/>`_ mapped classes.


Documentation
-------------

Latest documentation is at:
`Read The Docs <http://readthedocs.org/docs/colanderalchemy/en/latest/index.html>`_.


Installation
------------

Using `pip` command:  pip install ColanderAlchemy


License
-------

ColanderAlchemy is distributed under the `MIT license
<http://www.opensource.org/licenses/mit-license.php>`_.


Development version
-------------------

Fork the development version on
`GitHub <https://github.com/stefanofontanelli/ColanderAlchemy>`_.

On Python < 2.7 install unittest2 manually to run tests.


Support
-------

Please use `Github Issue System
<https://github.com/stefanofontanelli/ColanderAlchemy/issues/new>`_
for support requests (bug report, feature requests, 
other kind of help requests).

`Follow me on Twitter @stefontanelli
<https://twitter.com/stefontanelli>`_
to receive notifications about new releases.